pub fn lift(arch: RiscVArch, data: &[u8]) -> NnilExpand description
Lifts a complete diagnostic byte slice from guest address zero.
This path does not use MMU permission checks. The runtime uses lift_block instead.
pub fn lift(arch: RiscVArch, data: &[u8]) -> NnilLifts a complete diagnostic byte slice from guest address zero.
This path does not use MMU permission checks. The runtime uses lift_block instead.